'''
Description: A program to add parties for candidates (from a csv) to a csv of election results 
Author: Tiffany Xiao
Date Last Edited: 11/6/2019 
'''
import csv
import os

def read_csv_parties(name_of_csv):
    ''' Function to read the csv with a mapping from candidate to party, and create a dictionary from it '''
    # initialize dictionary
    candidate_parties = {}
    # add info to dictionary (loop through file and add keys & values)
    with open(name_of_csv) as csv_file:
        csv_reader = csv.reader(csv_file, delimiter=',')
        line_count = 0 
        for row in csv_reader:
            if line_count != 0: 
                candidate_parties[row[0]] = row[1]
            line_count += 1
    
    return candidate_parties

def read_write_elections(candidates_parties_dict, input):
    ''' Function reads the election csv and writes the party for each candidate '''
    tmpFile = "tmp.csv"
    with open(input, "r") as file, open(tmpFile, "w") as outFile:
        reader = csv.reader(file, delimiter=',')
        writer = csv.writer(outFile, delimiter=',')
        header = next(reader)
        writer.writerow(header)
        for row in reader:
            colValues = []
            for i in range(len(row)):
                # add party for candidate 
                if (i == 4):
                    colValues.append(candidates_parties_dict[row[5]])
                else:
                    colValues.append(row[i])
            writer.writerow(colValues)
    os.rename(tmpFile, input)

def main():
    ''' Main function that runs other functions using file names (change file names here)''' 
    # call function to read csv with candidates and their party 
    candidate_parties_dict = read_csv_parties("sonoma_2018_candidate_party_mapping.csv")

    # call function to add all the candidate party info to the csv with election results
    read_write_elections(candidate_parties_dict, "20181126__ca__general__sonoma__precinct.csv")

if __name__ == "__main__":
    main()